rest\_witchcraft package
========================

.. automodule:: rest_witchcraft
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   rest_witchcraft.field_mapping
   rest_witchcraft.fields
   rest_witchcraft.generics
   rest_witchcraft.mixins
   rest_witchcraft.routers
   rest_witchcraft.serializers
   rest_witchcraft.utils
   rest_witchcraft.viewsets

